# Relationship types

The following table lists all the possible relation semantics found in the Graph Dataset.

Note: the labels used to specify the semantic of the relationships are (for the large) inherited from the [DataCite metadata kernel](https://schema.datacite.org/meta/kernel-4.4/doc/DataCite-MetadataKernel_v4.4.pdf), which provides a description for them.

|  # | Source entity type                     | Target entity type                     | Relation name / inverse                                    | Provenance                                      |
|:--:|:--------------------------------------:|:--------------------------------------:|:----------------------------------------------------------:|:-----------------------------------------------:|
| 1  | [Project](/data-model/entities/project)            | [ResearchProduct](../../data-model/entities/research-product)              | produces / isProducedBy                                    | Harvested, Inferred by OpenAIRE, Linked by user |
| 2  | [Project](/data-model/entities/project)            | [Organization](/data-model/entities/organization)  | hasParticipant / isParticipant                             | Harvested                                       |
| 3  | [Project](/data-model/entities/project)            | [Community](/data-model/entities/community)        | IsRelatedTo / IsRelatedTo                                  | Linked by user                                  |
| 4  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsAmongTopNSimilarDocuments / HasAmongTopNSimilarDocuments | Inferred by OpenAIRE                            |
| 5  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsSupplementTo / IsSupplementedBy                          | Harvested                                       |
| 6  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsRelatedTo / IsRelatedTo                                  | Harvested, Inferred by OpenAIRE, Linked by user |
| 7  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsPartOf / HasPart                                         | Harvested                                       |
| 8  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsDocumentedBy / Documents                                 | Harvested                                       |
| 9  | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsObsoletedBy / Obsoletes                                  | Harvested                                       |
| 10 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsSourceOf / IsDerivedFrom                                 | Harvested                                       |
| 11 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsCompiledBy / Compiles                                    | Harvested                                       |
| 12 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsRequiredBy / Requires                                    | Harvested                                       |
| 13 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsCitedBy / Cites                                          | Harvested, Inferred by OpenAIRE                 |
| 14 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsReferencedBy / References                                | Harvested                                       |
| 15 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsReviewedBy / Reviews                                     | Harvested                                       |
| 16 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsOriginalFormOf / IsVariantFormOf                         | Harvested                                       |
| 17 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsVersionOf / HasVersion                                   | Harvested                                       |
| 18 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsIdenticalTo / IsIdenticalTo                              | Harvested                                       |
| 19 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsPreviousVersionOf / IsNewVersionOf                       | Harvested                                       |
| 20 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsContinuedBy / Continues                                  | Harvested                                       |
| 21 | [ResearchProduct](../../data-model/entities/research-product)              | [ResearchProduct](../../data-model/entities/research-product)              | IsDescribedBy / Describes                                  | Harvested                                       |
| 22 | [ResearchProduct](../../data-model/entities/research-product)              | [Organization](/data-model/entities/organization)  | hasAuthorInstitution / isAuthorInstitutionOf               | Harvested, Inferred by OpenAIRE                 |
| 23 | [ResearchProduct](../../data-model/entities/research-product)              | [Data source](/data-model/entities/data-source)    | isHostedBy / hosts                                         | Harvested, Inferred by OpenAIRE                 |
| 24 | [ResearchProduct](../../data-model/entities/research-product)              | [Data source](/data-model/entities/data-source)    | isProvidedBy / provides                                    | Harvested                                       |
| 25 | [ResearchProduct](../../data-model/entities/research-product)              | [Community](/data-model/entities/community)        | IsRelatedTo / IsRelatedTo                                  | Harvested, Inferred by OpenAIRE, Linked by user |
| 26 | [Organization](/data-model/entities/organization)  | [Community](/data-model/entities/community)        | IsRelatedTo / IsRelatedTo                                  | Linked by user                                  |
| 27 | [Organization](/data-model/entities/organization)  | [Organization](/data-model/entities/organization)  | IsChildOf / IsParentOf                                     | Linked by user                                  |
| 28 | [Data source](/data-model/entities/data-source)    | [Community](/data-model/entities/community)        | IsRelatedTo / IsRelatedTo                                  | Linked by user                                  |
| 29 | [Data source](/data-model/entities/data-source)    | [Organization](/data-model/entities/organization)  | isProvidedBy / provides                                    | Harvested                                       |
